Documentation
¶
Index ¶
- func DataArchiveFile_IsConstruct(x interface{}) *bool
- func DataArchiveFile_TfResourceType() *string
- func NewDataArchiveFileSourceList_Override(d DataArchiveFileSourceList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewDataArchiveFileSourceOutputReference_Override(d DataArchiveFileSourceOutputReference, ...)
- func NewDataArchiveFile_Override(d DataArchiveFile, scope constructs.Construct, id *string, ...)
- type DataArchiveFile
- type DataArchiveFileConfig
- type DataArchiveFileSource
- type DataArchiveFileSourceList
- type DataArchiveFileSourceOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataArchiveFile_IsConstruct ¶
func DataArchiveFile_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataArchiveFile_TfResourceType ¶
func DataArchiveFile_TfResourceType() *string
func NewDataArchiveFileSourceList_Override ¶
func NewDataArchiveFileSourceList_Override(d DataArchiveFileSourceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataArchiveFileSourceOutputReference_Override ¶
func NewDataArchiveFileSourceOutputReference_Override(d DataArchiveFileSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataArchiveFile_Override ¶
func NewDataArchiveFile_Override(d DataArchiveFile, scope constructs.Construct, id *string, config *DataArchiveFileConfig)
Create a new {@link https://www.terraform.io/docs/providers/archive/d/file archive_file} Data Source.
Types ¶
type DataArchiveFile ¶
type DataArchiveFile interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Excludes() *[]*string
SetExcludes(val *[]*string)
ExcludesInput() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
OutputBase64Sha256() *string
OutputFileMode() *string
SetOutputFileMode(val *string)
OutputFileModeInput() *string
OutputMd5() *string
OutputPath() *string
SetOutputPath(val *string)
OutputPathInput() *string
OutputSha() *string
OutputSize() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Source() DataArchiveFileSourceList
SourceContent() *string
SetSourceContent(val *string)
SourceContentFilename() *string
SetSourceContentFilename(val *string)
SourceContentFilenameInput() *string
SourceContentInput() *string
SourceDir() *string
SetSourceDir(val *string)
SourceDirInput() *string
SourceFile() *string
SetSourceFile(val *string)
SourceFileInput() *string
SourceInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSource(value interface{})
ResetExcludes()
ResetId()
ResetOutputFileMode()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetSource()
ResetSourceContent()
ResetSourceContentFilename()
ResetSourceDir()
ResetSourceFile()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/archive/d/file archive_file}.
func NewDataArchiveFile ¶
func NewDataArchiveFile(scope constructs.Construct, id *string, config *DataArchiveFileConfig) DataArchiveFile
Create a new {@link https://www.terraform.io/docs/providers/archive/d/file archive_file} Data Source.
type DataArchiveFileConfig ¶
type DataArchiveFileConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#output_path DataArchiveFile#output_path}.
OutputPath *string `field:"required" json:"outputPath" yaml:"outputPath"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#type DataArchiveFile#type}.
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#excludes DataArchiveFile#excludes}.
Excludes *[]*string `field:"optional" json:"excludes" yaml:"excludes"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#id DataArchiveFile#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#output_file_mode DataArchiveFile#output_file_mode}.
OutputFileMode *string `field:"optional" json:"outputFileMode" yaml:"outputFileMode"`
// source block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#source DataArchiveFile#source}
Source interface{} `field:"optional" json:"source" yaml:"source"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#source_content DataArchiveFile#source_content}.
SourceContent *string `field:"optional" json:"sourceContent" yaml:"sourceContent"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#source_content_filename DataArchiveFile#source_content_filename}.
SourceContentFilename *string `field:"optional" json:"sourceContentFilename" yaml:"sourceContentFilename"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#source_dir DataArchiveFile#source_dir}.
SourceDir *string `field:"optional" json:"sourceDir" yaml:"sourceDir"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#source_file DataArchiveFile#source_file}.
SourceFile *string `field:"optional" json:"sourceFile" yaml:"sourceFile"`
}
type DataArchiveFileSource ¶
type DataArchiveFileSource struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#content DataArchiveFile#content}.
Content *string `field:"required" json:"content" yaml:"content"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#filename DataArchiveFile#filename}.
Filename *string `field:"required" json:"filename" yaml:"filename"`
}
type DataArchiveFileSourceList ¶
type DataArchiveFileSourceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataArchiveFileSourceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataArchiveFileSourceList ¶
func NewDataArchiveFileSourceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataArchiveFileSourceList
type DataArchiveFileSourceOutputReference ¶
type DataArchiveFileSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Content() *string
SetContent(val *string)
ContentInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Filename() *string
SetFilename(val *string)
FilenameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataArchiveFileSourceOutputReference ¶
func NewDataArchiveFileSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataArchiveFileSourceOutputReference
Source Files
¶
- dataarchivefile.go
- dataarchivefile_DataArchiveFile.go
- dataarchivefile_DataArchiveFileConfig.go
- dataarchivefile_DataArchiveFileSource.go
- dataarchivefile_DataArchiveFileSourceList.go
- dataarchivefile_DataArchiveFileSourceList__runtime_type_checks.go
- dataarchivefile_DataArchiveFileSourceOutputReference.go
- dataarchivefile_DataArchiveFileSourceOutputReference__runtime_type_checks.go
- dataarchivefile_DataArchiveFile__runtime_type_checks.go