Documentation
¶
Index ¶
- func ArchiveProvider_IsConstruct(x interface{}) *bool
- func ArchiveProvider_IsTerraformElement(x interface{}) *bool
- func ArchiveProvider_IsTerraformProvider(x interface{}) *bool
- func ArchiveProvider_TfResourceType() *string
- func NewArchiveProvider_Override(a ArchiveProvider, scope constructs.Construct, id *string, ...)
- type ArchiveProvider
- type ArchiveProviderConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ArchiveProvider_IsConstruct ¶
func ArchiveProvider_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func ArchiveProvider_IsTerraformElement ¶
func ArchiveProvider_IsTerraformElement(x interface{}) *bool
Experimental.
func ArchiveProvider_IsTerraformProvider ¶
func ArchiveProvider_IsTerraformProvider(x interface{}) *bool
Experimental.
func ArchiveProvider_TfResourceType ¶
func ArchiveProvider_TfResourceType() *string
func NewArchiveProvider_Override ¶
func NewArchiveProvider_Override(a ArchiveProvider, scope constructs.Construct, id *string, config *ArchiveProviderConfig)
Create a new {@link https://www.terraform.io/docs/providers/archive archive} Resource.
Types ¶
type ArchiveProvider ¶
type ArchiveProvider interface {
cdktf.TerraformProvider
Alias() *string
SetAlias(val *string)
AliasInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
// Experimental.
MetaAttributes() *map[string]interface{}
// The tree node.
Node() constructs.Node
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformProviderSource() *string
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetAlias()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/archive archive}.
func NewArchiveProvider ¶
func NewArchiveProvider(scope constructs.Construct, id *string, config *ArchiveProviderConfig) ArchiveProvider
Create a new {@link https://www.terraform.io/docs/providers/archive archive} Resource.
type ArchiveProviderConfig ¶
type ArchiveProviderConfig struct {
// Alias name.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive#alias ArchiveProvider#alias}
Alias *string `field:"optional" json:"alias" yaml:"alias"`
}